pub struct AnalysisOutput {
pub formatted: String,
pub files: Vec<FileInfo>,
pub entries: Vec<WalkEntry>,
pub next_cursor: Option<String>,
}Expand description
Result of directory analysis containing both formatted output and file data.
Fields
formatted: Stringfiles: Vec<FileInfo>entries: Vec<WalkEntry>Walk entries used internally for summary generation; not serialized.
next_cursor: Option<String>Trait Implementations
Sourceimpl Debug for AnalysisOutput
impl Debug for AnalysisOutput
Sourceimpl JsonSchema for AnalysisOutput
impl JsonSchema for AnalysisOutput
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for AnalysisOutput
impl RefUnwindSafe for AnalysisOutput
impl Send for AnalysisOutput
impl Sync for AnalysisOutput
impl Unpin for AnalysisOutput
impl UnsafeUnpin for AnalysisOutput
impl UnwindSafe for AnalysisOutput