pub struct CallChainEntry {
pub symbol: String,
pub file: String,
pub line: usize,
}Expand description
Single entry in a call chain (depth-1 direct caller or callee).
Fields
symbol: Stringfile: Stringline: usizeTrait Implementations
Sourceimpl Clone for CallChainEntry
impl Clone for CallChainEntry
Sourcefn clone(&self) -> CallChainEntry
fn clone(&self) -> CallChainEntry
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for CallChainEntry
impl Debug for CallChainEntry
Sourceimpl<'de> Deserialize<'de> for CallChainEntry
impl<'de> Deserialize<'de> for CallChainEntry
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<CallChainEntry, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<CallChainEntry, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for CallChainEntry
impl JsonSchema for CallChainEntry
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl Serialize for CallChainEntry
impl Serialize for CallChainEntry
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more