pub struct FileAnalysisOutput {
pub formatted: String,
pub semantic: SemanticAnalysis,
pub line_count: usize,
pub next_cursor: Option<String>,
}Expand description
Result of file-level semantic analysis.
Fields
formatted: Stringsemantic: SemanticAnalysisline_count: usizenext_cursor: Option<String>Trait Implementations
Sourceimpl Clone for FileAnalysisOutput
impl Clone for FileAnalysisOutput
Sourcefn clone(&self) -> FileAnalysisOutput
fn clone(&self) -> FileAnalysisOutput
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for FileAnalysisOutput
impl Debug for FileAnalysisOutput
Sourceimpl JsonSchema for FileAnalysisOutput
impl JsonSchema for FileAnalysisOutput
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for FileAnalysisOutput
impl RefUnwindSafe for FileAnalysisOutput
impl Send for FileAnalysisOutput
impl Sync for FileAnalysisOutput
impl Unpin for FileAnalysisOutput
impl UnsafeUnpin for FileAnalysisOutput
impl UnwindSafe for FileAnalysisOutput