pub struct AnalysisCache { /* private fields */ }Expand description
LRU cache for file analysis results with mutex protection.
Implementations
Sourceimpl AnalysisCache
impl AnalysisCache
Sourcepub fn get(&self, key: &CacheKey) -> Option<Arc<FileAnalysisOutput>>
pub fn get(&self, key: &CacheKey) -> Option<Arc<FileAnalysisOutput>>
Get a cached analysis result if it exists.
Sourcepub fn put(&self, key: CacheKey, value: Arc<FileAnalysisOutput>)
pub fn put(&self, key: CacheKey, value: Arc<FileAnalysisOutput>)
Store an analysis result in the cache.
Sourcepub fn get_directory(
&self,
key: &DirectoryCacheKey,
) -> Option<Arc<AnalysisOutput>>
pub fn get_directory( &self, key: &DirectoryCacheKey, ) -> Option<Arc<AnalysisOutput>>
Get a cached directory analysis result if it exists.
Sourcepub fn put_directory(&self, key: DirectoryCacheKey, value: Arc<AnalysisOutput>)
pub fn put_directory(&self, key: DirectoryCacheKey, value: Arc<AnalysisOutput>)
Store a directory analysis result in the cache.