Module languages

Module languages 

Modules

go
java
python
rust
typescript

Structs

LanguageInfo
Information about a supported language for code analysis.

Functions

get_language_info
Get language information by language name.

Type Aliases

ExtractFunctionNameHandler
Handler to extract function name from a node.
ExtractInheritanceHandler
Handler to extract inheritance information from a class node.
FindMethodForReceiverHandler
Handler to find method name for a receiver type.
FindReceiverTypeHandler
Handler to find receiver type for a method.