pub enum AnalyzeFileField {
Functions,
Classes,
Imports,
}Expand description
Output section selector for analyze_file fields projection.
Variants
Functions
Include function definitions with signatures, types, and line ranges.
Classes
Include class and method definitions with inheritance and fields.
Imports
Include import statements.