pub struct AnalysisResult {
pub path: String,
pub mode: AnalysisMode,
pub import_count: usize,
pub main_line: Option<usize>,
pub files: Vec<FileInfo>,
pub functions: Vec<FunctionInfo>,
pub classes: Vec<ClassInfo>,
pub references: Vec<ReferenceInfo>,
}Fields
path: Stringmode: AnalysisModeimport_count: usizemain_line: Option<usize>files: Vec<FileInfo>functions: Vec<FunctionInfo>classes: Vec<ClassInfo>references: Vec<ReferenceInfo>Trait Implementations
Sourceimpl Clone for AnalysisResult
impl Clone for AnalysisResult
Sourcefn clone(&self) -> AnalysisResult
fn clone(&self) -> AnalysisResult
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for AnalysisResult
impl Debug for AnalysisResult
Sourceimpl<'de> Deserialize<'de> for AnalysisResult
impl<'de> Deserialize<'de> for AnalysisResult
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for AnalysisResult
impl JsonSchema for AnalysisResult
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for AnalysisResult
impl RefUnwindSafe for AnalysisResult
impl Send for AnalysisResult
impl Sync for AnalysisResult
impl Unpin for AnalysisResult
impl UnsafeUnpin for AnalysisResult
impl UnwindSafe for AnalysisResult