pub struct AnalyzeDirectoryParams {
pub path: String,
pub max_depth: Option<u32>,
pub pagination: PaginationParams,
pub output_control: OutputControlParams,
}Fields
path: StringDirectory path to analyze
max_depth: Option<u32>Maximum directory traversal depth for overview mode only. 0 or unset = unlimited depth. Use 1-3 for large monorepos to manage output size. Ignored in other modes.
pagination: PaginationParamsoutput_control: OutputControlParamsTrait Implementations
Sourceimpl Clone for AnalyzeDirectoryParams
impl Clone for AnalyzeDirectoryParams
Sourcefn clone(&self) -> AnalyzeDirectoryParams
fn clone(&self) -> AnalyzeDirectoryParams
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for AnalyzeDirectoryParams
impl Debug for AnalyzeDirectoryParams
Sourceimpl<'de> Deserialize<'de> for AnalyzeDirectoryParams
impl<'de> Deserialize<'de> for AnalyzeDirectoryParams
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for AnalyzeDirectoryParams
impl JsonSchema for AnalyzeDirectoryParams
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for AnalyzeDirectoryParams
impl RefUnwindSafe for AnalyzeDirectoryParams
impl Send for AnalyzeDirectoryParams
impl Sync for AnalyzeDirectoryParams
impl Unpin for AnalyzeDirectoryParams
impl UnsafeUnpin for AnalyzeDirectoryParams
impl UnwindSafe for AnalyzeDirectoryParams