pub struct AnalyzeFileParams {
pub path: String,
pub ast_recursion_limit: Option<usize>,
pub pagination: PaginationParams,
pub output_control: OutputControlParams,
}Fields
path: StringFile path to analyze
ast_recursion_limit: Option<usize>Maximum AST node depth for tree-sitter queries. Internal tuning parameter; leave unset in normal use. Increase only if query results are missing constructs in deeply nested or generated code.
pagination: PaginationParamsoutput_control: OutputControlParamsTrait Implementations
Sourceimpl Clone for AnalyzeFileParams
impl Clone for AnalyzeFileParams
Sourcefn clone(&self) -> AnalyzeFileParams
fn clone(&self) -> AnalyzeFileParams
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for AnalyzeFileParams
impl Debug for AnalyzeFileParams
Sourceimpl<'de> Deserialize<'de> for AnalyzeFileParams
impl<'de> Deserialize<'de> for AnalyzeFileParams
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for AnalyzeFileParams
impl JsonSchema for AnalyzeFileParams
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for AnalyzeFileParams
impl RefUnwindSafe for AnalyzeFileParams
impl Send for AnalyzeFileParams
impl Sync for AnalyzeFileParams
impl Unpin for AnalyzeFileParams
impl UnsafeUnpin for AnalyzeFileParams
impl UnwindSafe for AnalyzeFileParams