pub struct AnalyzeParams {
pub path: String,
pub mode: Option<AnalysisMode>,
pub max_depth: Option<u32>,
pub focus: Option<String>,
pub follow_depth: Option<u32>,
pub ast_recursion_limit: Option<usize>,
pub force: Option<bool>,
pub summary: Option<bool>,
pub cursor: Option<String>,
pub page_size: Option<usize>,
}Fields
path: Stringmode: Option<AnalysisMode>max_depth: Option<u32>focus: Option<String>follow_depth: Option<u32>ast_recursion_limit: Option<usize>force: Option<bool>summary: Option<bool>cursor: Option<String>page_size: Option<usize>Trait Implementations
Sourceimpl Clone for AnalyzeParams
impl Clone for AnalyzeParams
Sourcefn clone(&self) -> AnalyzeParams
fn clone(&self) -> AnalyzeParams
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for AnalyzeParams
impl Debug for AnalyzeParams
Sourceimpl<'de> Deserialize<'de> for AnalyzeParams
impl<'de> Deserialize<'de> for AnalyzeParams
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for AnalyzeParams
impl JsonSchema for AnalyzeParams
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for AnalyzeParams
impl RefUnwindSafe for AnalyzeParams
impl Send for AnalyzeParams
impl Sync for AnalyzeParams
impl Unpin for AnalyzeParams
impl UnsafeUnpin for AnalyzeParams
impl UnwindSafe for AnalyzeParams