pub struct CallChain {
pub chain: Vec<CallInfo>,
pub depth: u32,
}Fields
chain: Vec<CallInfo>depth: u32Trait Implementations
Sourceimpl<'de> Deserialize<'de> for CallChain
impl<'de> Deserialize<'de> for CallChain
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for CallChain
impl JsonSchema for CallChain
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for CallChain
impl RefUnwindSafe for CallChain
impl Send for CallChain
impl Sync for CallChain
impl Unpin for CallChain
impl UnsafeUnpin for CallChain
impl UnwindSafe for CallChain