pub struct CallEdge {
pub path: PathBuf,
pub line: usize,
pub neighbor_name: String,
pub is_impl_trait: bool,
}Expand description
A single edge in the call graph with impl-trait metadata.
neighbor_name holds the caller name in callers maps and the callee name in callees maps.
Fields
path: PathBufline: usizeneighbor_name: Stringis_impl_trait: boolTrait Implementations
impl StructuralPartialEq for CallEdge