pub struct CallInfo {
pub caller: String,
pub callee: String,
pub line: usize,
pub column: usize,
pub arg_count: Option<usize>,
}Fields
caller: Stringcallee: Stringline: usizecolumn: usizearg_count: Option<usize>Trait Implementations
Sourceimpl<'de> Deserialize<'de> for CallInfo
impl<'de> Deserialize<'de> for CallInfo
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for CallInfo
impl JsonSchema for CallInfo
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for CallInfo
impl RefUnwindSafe for CallInfo
impl Send for CallInfo
impl Sync for CallInfo
impl Unpin for CallInfo
impl UnsafeUnpin for CallInfo
impl UnwindSafe for CallInfo