pub struct FileInfo {
pub path: String,
pub language: String,
pub line_count: usize,
pub function_count: usize,
pub class_count: usize,
pub is_test: bool,
}Fields
path: Stringlanguage: Stringline_count: usizefunction_count: usizeclass_count: usizeis_test: boolTrait Implementations
Sourceimpl<'de> Deserialize<'de> for FileInfo
impl<'de> Deserialize<'de> for FileInfo
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for FileInfo
impl JsonSchema for FileInfo
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for FileInfo
impl RefUnwindSafe for FileInfo
impl Send for FileInfo
impl Sync for FileInfo
impl Unpin for FileInfo
impl UnsafeUnpin for FileInfo
impl UnwindSafe for FileInfo