pub struct FocusedAnalysisData {
pub symbol: String,
pub definition: Option<FunctionInfo>,
pub call_chains: Vec<CallChain>,
pub references: Vec<ReferenceInfo>,
}Fields
symbol: Stringdefinition: Option<FunctionInfo>call_chains: Vec<CallChain>references: Vec<ReferenceInfo>Trait Implementations
Sourceimpl Clone for FocusedAnalysisData
impl Clone for FocusedAnalysisData
Sourcefn clone(&self) -> FocusedAnalysisData
fn clone(&self) -> FocusedAnalysisData
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for FocusedAnalysisData
impl Debug for FocusedAnalysisData
Sourceimpl<'de> Deserialize<'de> for FocusedAnalysisData
impl<'de> Deserialize<'de> for FocusedAnalysisData
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for FocusedAnalysisData
impl JsonSchema for FocusedAnalysisData
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for FocusedAnalysisData
impl RefUnwindSafe for FocusedAnalysisData
impl Send for FocusedAnalysisData
impl Sync for FocusedAnalysisData
impl Unpin for FocusedAnalysisData
impl UnsafeUnpin for FocusedAnalysisData
impl UnwindSafe for FocusedAnalysisData