Module cache
code_
analyze_
mcp
0.1.1
Module cache
Module Items
Structs
In crate code_
analyze_
mcp
code_analyze_mcp
Module
cache
Structs

Analysis
Cache
LRU cache for file analysis results with mutex protection.
Cache
Key
Cache key combining path, modification time, and analysis mode.