Modules
Structs
- Language
Info - Information about a supported language for code analysis.
Functions
- get_
language_ info - Get language information by language name.
Type Aliases
- Extract
Function Name Handler - Handler to extract function name from a node.
- Extract
Inheritance Handler - Handler to extract inheritance information from a class node.
- Find
Method ForReceiver Handler - Handler to find method name for a receiver type.
- Find
Receiver Type Handler - Handler to find receiver type for a method.